# Psf Test

Psf Test is a font family used only for testing the pysilfont framework. It is not intended to be an installable font family and doesn't even contain a complete Latin alphabet (Z and z are missing). The contents of these fonts are taken from [Andika New Basic](https://scripts.sil.org/andika).

For copyright and licensing information - including any Reserved Font Names - see [OFL.txt](OFL.txt).

For practical information about using, modifying and redistributing this font see [OFL-FAQ.txt](OFL-FAQ.txt).

For more details about this project, including changelog and acknowledgements see [FONTLOG.txt](FONTLOG.txt) and [README.txt](README.txt).
